@@ -1,3 +1,4 @@
+import re
 from functools import partial
 
 from content_editor.models import Type
@@ -13,18 +14,6 @@ from django.utils.translation import gettext_lazy as _
 from feincms3.utils import ChoicesCharField, validation_error
 
 
-def import_if_string(obj_or_path):
-    return import_string(obj_or_path) if isinstance(obj_or_path, str) else obj_or_path
-
-
-class ImportDescriptor:
-    def __set_name__(self, owner, name):
-        self._name = name
-
-    def __get__(self, obj, type=None):
-        return import_if_string(obj.get(self._name))
-
-
 class FormType(Type):
     _REQUIRED = {"key", "label", "regions", "form_class", "validate"}
 
@@ -33,14 +22,19 @@ class FormType(Type):
         kwargs.setdefault("validate", lambda configured_form: [])
         super().__init__(**kwargs)
 
-    form_class = ImportDescriptor()
-    process = ImportDescriptor()
-    validate = ImportDescriptor()
+    def __getattr__(self, attr):
+        value = super().__getattr__(attr)
+        if isinstance(value, str) and re.match(r"^\w+\.([\w\.]+)+$", value):
+            try:
+                return import_string(value)
+            except ModuleNotFoundError:
+                pass
+        return value
 
 
 class ConfiguredForm(models.Model):
     name = models.CharField(_("name"), max_length=1000)
-    form = ChoicesCharField(_("form"), max_length=100)
+    form_type = ChoicesCharField(_("form type"), max_length=100)
 
     class Meta:
         abstract = True
@@ -62,11 +56,11 @@ class ConfiguredForm(models.Model):
     @staticmethod
     def fill_form_choices(sender, **kwargs):
         if issubclass(sender, ConfiguredForm) and not sender._meta.abstract:
-            field = sender._meta.get_field("form")
+            field = sender._meta.get_field("form_type")
             field.choices = [(row["key"], row["label"]) for row in sender.FORMS]
 
             types = {type.key: type for type in sender.FORMS}
-            sender.type = property(lambda self: import_if_string(types.get(self.form)))
+            sender.type = property(lambda self: types.get(self.form_type))
 
     def get_formfields_union(self, *, plugins, values=["name"]):
         qs = None
